class Life:
    def __init__(self, name, lifespan):
        self.name = name
        self.lifespan = lifespan

    def get_name(self):
        return self.name

    def set_name(self, name):
        self.name = name

    def get_lifespan(self):
        return self.lifespan

    def set_lifespan(self, lifespan):
        self.lifespan = lifespan

    def define(self):
        print(f"{self.name} a une durée de vie de {self.lifespan} ans.")

    def se_definir(self):
        print(f"Je suis un être vivant nommé {self.name} avec une durée de vie de {self.lifespan} ans.")


class Humain(Life):
    def __init__(self, name, lifespan, profession):
        super().__init__(name, lifespan)
        self.profession = profession

    def get_profession(self):
        return self.profession

    def set_profession(self, profession):
        self.profession = profession

    def specific_function(self):
        print(f"{self.name} est un humain et sa profession est {self.profession}.")

    def se_definir(self):
        print(f"Je suis un humain nommé {self.name} avec une durée de vie de {self.lifespan} ans. "
              f"MA profession est {self.profession}.")



class Poisson(Life):
    def __init__(self, name, lifespan, habitat):
        super().__init__(name, lifespan)
        self.habitat = habitat

    def get_habitat(self):
        return self.habitat

    def set_habitat(self, habitat):
        self.habitat = habitat

    def specific_function(self):
        print(f"{self.name} est un poisson habitant {self.habitat}. ")

    def se_definir(self):
        print(f"Je suis un poisson nommé {self.name} avec une durée de vie de {self.lifespan} ans. "
              f"Mon habitat est {self.habitat}.")

    def nager(self):
        print(f"{self.name} nage dans son habitat, l'{self.habitat}.")
