from heritage import Life, Humain, Poisson

humain1 = Humain("Alice", 80, "Ingénieur")
poisson1 = Poisson("Nemo", 5, "Océan Pacifique")

humain1.define()
print(f"Profession de {humain1.get_name()} : {humain1.get_profession()}")
humain1.specific_function()
humain1.se_definir()

print("\n")

poisson1.define()
print(f"Habitat de {poisson1.get_name()} : {poisson1.get_habitat()}")
poisson1.specific_function()
poisson1.se_definir()
poisson1.nager()
